Explain

Trait Explain 

pub trait Explain:
    Error
    + Debug
    + Display
    + Send
    + Sync
    + AnyCast {
    // Required method
    fn as_zx_status(&self) -> Status;
}
All detailed error objects must implement the Explain trait, since:

  • Some operations are not yet refactored into bedrock.
  • Some operations fundamentally are not fit for bedrock.

The detailed errors are hidden, but users may get strings or codes for debugging.

Required Methods

Implementors